# PyPlugs

_Decorator based plug-in architecture for Python_

[![Latest version](https://img.shields.io/pypi/v/pyplugs.svg)](https://pypi.org/project/pyplugs/)
[![Python versions](https://img.shields.io/pypi/pyversions/pyplugs.svg)](https://pypi.org/project/pyplugs/)
[![License](https://img.shields.io/pypi/l/pyplugs.svg)](https://pypi.org/project/pyplugs/)
[![Ruff](https://img.shields.io/endpoint?url=https://raw.githubusercontent.com/astral-sh/ruff/main/assets/badge/v2.json)](https://github.com/astral-sh/ruff)
[![Linted](https://github.com/gahjelle/pyplugs/actions/workflows/lint.yml/badge.svg?branch=main)](https://github.com/gahjelle/pyplugs/actions/workflows/lint.yml)
[![Tested with Pytest](https://github.com/gahjelle/pyplugs/actions/workflows/test.yml/badge.svg?branch=main)](https://github.com/gahjelle/pyplugs/actions/workflows/test.yml)
[![Type checked with mypy](https://img.shields.io/badge/type%20checked-mypy-green)](http://mypy-lang.org/)
[![Interrogate DocStrings](https://raw.githubusercontent.com/gahjelle/pyplugs/main/docs/images/interrogate_badge.svg)](https://interrogate.readthedocs.io/)


## Installing PyPlugs

PyPlugs is available at [PyPI](https://pypi.org/project/pyplugs/). You can install it using Pip:

    $ python -m pip install pyplugs


## Using PyPlugs

...


## Installing From Source

You can always download the [latest version of PyPlugs from GitHub](https://github.com/gahjelle/pyplugs).